import openai

class GPT:
    def __init__(self, api_key: str):
        self.api_key = api_key
        openai.api_key = api_key

    def ask_from_input(self, prompt_message: str = "Ask your question: ", model: str = "gpt-3.5-turbo"):
        try:
            question = input(prompt_message)
            response = openai.ChatCompletion.create(
                model=model,
                messages=[{"role": "user", "content": question}],
            )
            return response['choices'][0]['message']['content']
        except openai.error.OpenAIError as e:
            return f"An error occurred: {e}"
            


from setuptools import setup, find_packages

setup(
    name="py-chatai",
    version="1.0.3",
    description="🔗 package guide on https://github.com/mohamedlunar/py-chatai",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="MohamedLunar",
    author_email="contact.mohamedlunardev@gmail.com",
    url="https://github.com/mohamedlunar/py-chatai",
    packages=find_packages(),
    install_requires=["openai"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
